Computation times — scikit-hubness 0.21.0 documentation

# Computation times

00:25.940 total execution time for documentation_auto_examples files:

- 00:25.940: Nearest Neighbors Classification (`plot_classification.py`)

- 00:00.000: Manifold learning on handwritten digits: Locally Linear Embedding, Isomap… (`plot_lle_digits.py`)

- 00:00.000: Face completion with a multi-output estimators (`plot_multioutput_face_completion.py`)

- 00:00.000: Comparing Nearest Neighbors with and without Neighborhood Components Analysis (`plot_nca_classification.py`)

- 00:00.000: Dimensionality Reduction with Neighborhood Components Analysis (`plot_nca_dim_reduction.py`)

- 00:00.000: Nearest Centroid Classification (`plot_nearest_centroid.py`)

- 00:00.000: Nearest Neighbors regression (`plot_regression.py`)